@@ -4,6 +4,6 @@
     To be documented
 """
 
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 
-from . import overlay
+from .overlay import *
